pub struct DisplayModel {
pub intent: String,
pub interpolated_intent: Option<String>,
pub entries: Vec<DisplayEntry>,
pub owner: Option<String>,
pub contract_name: Option<String>,
}Expand description
Output model for clear signing display.
Fields
intent: Stringinterpolated_intent: Option<String>entries: Vec<DisplayEntry>owner: Option<String>Owner of the descriptor that produced this model (from metadata.owner).
contract_name: Option<String>Trait Implementations
Sourceimpl Clone for DisplayModel
impl Clone for DisplayModel
Sourcefn clone(&self) -> DisplayModel
fn clone(&self) -> DisplayModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for DisplayModel
impl<UT> ConvertError<UT> for DisplayModel
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for DisplayModel
impl Debug for DisplayModel
Sourceimpl<UT> FfiConverter<UT> for DisplayModel
impl<UT> FfiConverter<UT> for DisplayModel
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for DisplayModel
impl<UT> Lift<UT> for DisplayModel
Sourceimpl<UT> LiftRef<UT> for DisplayModel
impl<UT> LiftRef<UT> for DisplayModel
type LiftType = DisplayModel
Sourceimpl<UT> LiftReturn<UT> for DisplayModel
impl<UT> LiftReturn<UT> for DisplayModel
Sourcetype ReturnType = <DisplayModel as Lift<UT>>::FfiType
type ReturnType = <DisplayModel as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for DisplayModel
impl<UT> Lower<UT> for DisplayModel
type FfiType = <DisplayModel as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for DisplayModel
impl<UT> LowerError<UT> for DisplayModel
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for DisplayModel
impl<UT> LowerReturn<UT> for DisplayModel
Sourcetype ReturnType = <DisplayModel as Lower<UT>>::FfiType
type ReturnType = <DisplayModel as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl Serialize for DisplayModel
impl Serialize for DisplayModel
Sourceimpl<UT> TypeId<UT> for DisplayModel
impl<UT> TypeId<UT> for DisplayModel