pub fn prepend_scope_path(field: &DisplayField, scope: &str) -> DisplayFieldExpand description
Prepend a scope path to all path fields in a DisplayField.
Per ERC-7730 spec, inline scope groups concatenate parent paths with child paths.
Also prepends to tokenPath in params when the token path is relative (no #. prefix).